/**
 * Enumerated data type that represents the different concrete
 *  FinchAction classes.  Provides facilities for each of the 
 *  enumerated types to describe themselves
 *   
 * @author Andrew H. Fagg
 * 
 */


public enum FinchActionType {
	FINCH_MOVE("Move"),
	FINCH_MOVE_GUARDED("Guarded Move"),
	FINCH_BUZZ("Buzz"),
	FINCH_NOSE("Nose"),
	FINCH_ORIENTATION_GUARDED("Guarded Orientation"),
	FINCH_OBSTACLE_GUARDED("Guarded Obstacle");
	
	/**
	 * String description of the enumerated value.  This string will be used in
	 * the GUI
	 */
	private String description;
	
	/**
	 * Primary constructor.
	 * 
	 * @param description A string description of the enumerated value.
	 */
	private FinchActionType(String description){
		this.description = description;
	}
	
	/**
	 * Return the set of FinchAction types
	 * 
	 * @return An array containing all of the FinchAction types
	 */
	static public FinchActionType[] getActionList(){
		return(FinchActionType.values());
	}
	
	/**
	 * Return a string that describes the enumerated value.
	 * 
	 * @return A string describing the FinchAction enumerated value
	 */
	public String toString(){
		return(description);
	}
	
}
